# Longitudinal checks

Longitudinal checks issue an aggregation SQL query (via `aggregation_sql()`) and analyse the resulting time series.

::: dqf.TrendCheck

::: dqf.StructuralBreakCheck

::: dqf.ProportionDriftCheck

::: dqf.KSDriftCheck

::: dqf.ChiSquaredDriftCheck

::: dqf.DistributionDriftCheck

::: dqf.SeasonalityCheck

::: dqf.ConceptDriftCheck
